Struct SubscribeEventsRequest
#[non_exhaustive]pub struct SubscribeEventsRequest {
pub read_mask: Option<FieldMask>,
pub filter: Option<EventFilter>,
}Expand description
Request message for SubscriptionService.SubscribeEvents.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.read_mask: Option<FieldMask>Optional. Mask for specifying which parts of the Event should be returned.
filter: Option<EventFilter>Optional. DNF filter over indexed dimensions. If absent, every event is streamed.
Implementations
impl SubscribeEventsRequest
impl SubscribeEventsRequest
pub const READ_MASK_FIELD: &'static MessageField
pub const FILTER_FIELD: &'static MessageField
impl SubscribeEventsRequest
impl SubscribeEventsRequest
pub fn path_builder() -> SubscribeEventsRequestFieldPathBuilder
impl SubscribeEventsRequest
impl SubscribeEventsRequest
pub const fn const_default() -> SubscribeEventsRequest
pub fn read_mask_opt_mut(&mut self) -> Option<&mut FieldMask>
pub fn read_mask_opt_mut(&mut self) -> Option<&mut FieldMask>
pub fn read_mask_mut(&mut self) -> &mut FieldMask
pub fn read_mask_mut(&mut self) -> &mut FieldMask
Returns a mutable reference to read_mask.
If the field is unset, it is first initialized with the default value.
pub fn read_mask_opt(&self) -> Option<&FieldMask>
pub fn read_mask_opt(&self) -> Option<&FieldMask>
pub fn set_read_mask<T>(&mut self, field: T)
pub fn set_read_mask<T>(&mut self, field: T)
Sets read_mask with the provided value.
pub fn with_read_mask<T>(self, field: T) -> SubscribeEventsRequest
pub fn with_read_mask<T>(self, field: T) -> SubscribeEventsRequest
Sets read_mask with the provided value.
pub fn filter(&self) -> &EventFilter
pub fn filter(&self) -> &EventFilter
Returns the value of filter, or the default value if filter is unset.
pub fn filter_opt_mut(&mut self) -> Option<&mut EventFilter>
pub fn filter_opt_mut(&mut self) -> Option<&mut EventFilter>
pub fn filter_mut(&mut self) -> &mut EventFilter
pub fn filter_mut(&mut self) -> &mut EventFilter
Returns a mutable reference to filter.
If the field is unset, it is first initialized with the default value.
pub fn filter_opt(&self) -> Option<&EventFilter>
pub fn filter_opt(&self) -> Option<&EventFilter>
pub fn set_filter<T>(&mut self, field: T)where
T: Into<EventFilter>,
pub fn set_filter<T>(&mut self, field: T)where
T: Into<EventFilter>,
Sets filter with the provided value.
pub fn with_filter<T>(self, field: T) -> SubscribeEventsRequestwhere
T: Into<EventFilter>,
pub fn with_filter<T>(self, field: T) -> SubscribeEventsRequestwhere
T: Into<EventFilter>,
Sets filter with the provided value.