TransactionLiteral

Struct TransactionLiteral 

#[non_exhaustive]
pub struct TransactionLiteral { pub negated: bool, pub predicate: Option<Predicate>, }
One signed transaction predicate literal: a predicate, optionally negated.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
negated: bool

When true, the literal matches transactions that the predicate does not match.

predicate: Option<Predicate>

The transaction-index predicate to match.

Implementations



impl TransactionLiteral

pub const NEGATED_FIELD: &'static MessageField

pub const SENDER_FIELD: &'static MessageField

pub const AFFECTED_ADDRESS_FIELD: &'static MessageField

pub const AFFECTED_OBJECT_FIELD: &'static MessageField

pub const MOVE_CALL_FIELD: &'static MessageField

pub const EMIT_MODULE_FIELD: &'static MessageField

pub const EVENT_TYPE_FIELD: &'static MessageField

pub const EVENT_STREAM_HEAD_FIELD: &'static MessageField

pub const PACKAGE_WRITE_FIELD: &'static MessageField



impl TransactionLiteral

pub fn path_builder() -> TransactionLiteralFieldPathBuilder



impl TransactionLiteral

pub const fn const_default() -> TransactionLiteral

pub fn negated_mut(&mut self) -> &mut bool

Returns a mutable reference to negated. If the field is unset, it is first initialized with the default value.

pub fn set_negated(&mut self, field: bool)

Sets negated with the provided value.

pub fn with_negated(self, field: bool) -> TransactionLiteral

Sets negated with the provided value.

pub fn sender(&self) -> &SenderFilter

Returns the value of sender, or the default value if sender is unset.

pub fn sender_opt(&self) -> Option<&SenderFilter>

If sender is set, returns Some with the value; otherwise returns None.

pub fn sender_opt_mut(&mut self) -> Option<&mut SenderFilter>

If sender is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn sender_mut(&mut self) -> &mut SenderFilter

Returns a mutable reference to sender. If the field is unset, it is first initialized with the default value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn set_sender<T>(&mut self, field: T)
where T: Into<SenderFilter>,

Sets sender with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn with_sender<T>(self, field: T) -> TransactionLiteral
where T: Into<SenderFilter>,

Sets sender with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn affected_address(&self) -> &AffectedAddressFilter

Returns the value of affected_address, or the default value if affected_address is unset.

pub fn affected_address_opt(&self) -> Option<&AffectedAddressFilter>

If affected_address is set, returns Some with the value; otherwise returns None.

pub fn affected_address_opt_mut(&mut self) -> Option<&mut AffectedAddressFilter>

If affected_address is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn affected_address_mut(&mut self) -> &mut AffectedAddressFilter

Returns a mutable reference to affected_address. If the field is unset, it is first initialized with the default value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn set_affected_address<T>(&mut self, field: T)

Sets affected_address with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn with_affected_address<T>(self, field: T) -> TransactionLiteral

Sets affected_address with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn affected_object(&self) -> &AffectedObjectFilter

Returns the value of affected_object, or the default value if affected_object is unset.

pub fn affected_object_opt(&self) -> Option<&AffectedObjectFilter>

If affected_object is set, returns Some with the value; otherwise returns None.

pub fn affected_object_opt_mut(&mut self) -> Option<&mut AffectedObjectFilter>

If affected_object is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn affected_object_mut(&mut self) -> &mut AffectedObjectFilter

Returns a mutable reference to affected_object. If the field is unset, it is first initialized with the default value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn set_affected_object<T>(&mut self, field: T)

Sets affected_object with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn with_affected_object<T>(self, field: T) -> TransactionLiteral

Sets affected_object with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn move_call(&self) -> &MoveCallFilter

Returns the value of move_call, or the default value if move_call is unset.

pub fn move_call_opt(&self) -> Option<&MoveCallFilter>

If move_call is set, returns Some with the value; otherwise returns None.

pub fn move_call_opt_mut(&mut self) -> Option<&mut MoveCallFilter>

If move_call is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn move_call_mut(&mut self) -> &mut MoveCallFilter

Returns a mutable reference to move_call. If the field is unset, it is first initialized with the default value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn set_move_call<T>(&mut self, field: T)
where T: Into<MoveCallFilter>,

Sets move_call with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn with_move_call<T>(self, field: T) -> TransactionLiteral
where T: Into<MoveCallFilter>,

Sets move_call with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn emit_module(&self) -> &EmitModuleFilter

Returns the value of emit_module, or the default value if emit_module is unset.

pub fn emit_module_opt(&self) -> Option<&EmitModuleFilter>

If emit_module is set, returns Some with the value; otherwise returns None.

pub fn emit_module_opt_mut(&mut self) -> Option<&mut EmitModuleFilter>

If emit_module is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn emit_module_mut(&mut self) -> &mut EmitModuleFilter

Returns a mutable reference to emit_module. If the field is unset, it is first initialized with the default value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn set_emit_module<T>(&mut self, field: T)

Sets emit_module with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn with_emit_module<T>(self, field: T) -> TransactionLiteral

Sets emit_module with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn event_type(&self) -> &EventTypeFilter

Returns the value of event_type, or the default value if event_type is unset.

pub fn event_type_opt(&self) -> Option<&EventTypeFilter>

If event_type is set, returns Some with the value; otherwise returns None.

pub fn event_type_opt_mut(&mut self) -> Option<&mut EventTypeFilter>

If event_type is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn event_type_mut(&mut self) -> &mut EventTypeFilter

Returns a mutable reference to event_type. If the field is unset, it is first initialized with the default value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn set_event_type<T>(&mut self, field: T)

Sets event_type with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn with_event_type<T>(self, field: T) -> TransactionLiteral

Sets event_type with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn event_stream_head(&self) -> &EventStreamHeadFilter

Returns the value of event_stream_head, or the default value if event_stream_head is unset.

pub fn event_stream_head_opt(&self) -> Option<&EventStreamHeadFilter>

If event_stream_head is set, returns Some with the value; otherwise returns None.

pub fn event_stream_head_opt_mut( &mut self, ) -> Option<&mut EventStreamHeadFilter>

If event_stream_head is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn event_stream_head_mut(&mut self) -> &mut EventStreamHeadFilter

Returns a mutable reference to event_stream_head. If the field is unset, it is first initialized with the default value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn set_event_stream_head<T>(&mut self, field: T)

Sets event_stream_head with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn with_event_stream_head<T>(self, field: T) -> TransactionLiteral

Sets event_stream_head with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn package_write(&self) -> &PackageWriteFilter

Returns the value of package_write, or the default value if package_write is unset.

pub fn package_write_opt(&self) -> Option<&PackageWriteFilter>

If package_write is set, returns Some with the value; otherwise returns None.

pub fn package_write_opt_mut(&mut self) -> Option<&mut PackageWriteFilter>

If package_write is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn package_write_mut(&mut self) -> &mut PackageWriteFilter

Returns a mutable reference to package_write. If the field is unset, it is first initialized with the default value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn set_package_write<T>(&mut self, field: T)

Sets package_write with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn with_package_write<T>(self, field: T) -> TransactionLiteral

Sets package_write with the provided value. If any other oneof field in the same oneof is set, it will be cleared.



impl TransactionLiteral

pub fn negate(self) -> TransactionLiteral

Negate this literal: require that its predicate not match.