Struct TransactionLiteral
#[non_exhaustive]pub struct TransactionLiteral {
pub negated: bool,
pub predicate: Option<Predicate>,
}Expand description
One signed transaction predicate literal: a predicate, optionally negated.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.negated: boolWhen true, the literal matches transactions that the predicate does not match.
predicate: Option<Predicate>The transaction-index predicate to match.
Implementations
impl TransactionLiteral
impl TransactionLiteral
pub const NEGATED_FIELD: &'static MessageField
pub const SENDER_FIELD: &'static MessageField
pub const AFFECTED_ADDRESS_FIELD: &'static MessageField
pub const AFFECTED_OBJECT_FIELD: &'static MessageField
pub const MOVE_CALL_FIELD: &'static MessageField
pub const EMIT_MODULE_FIELD: &'static MessageField
pub const EVENT_TYPE_FIELD: &'static MessageField
pub const EVENT_STREAM_HEAD_FIELD: &'static MessageField
pub const PACKAGE_WRITE_FIELD: &'static MessageField
impl TransactionLiteral
impl TransactionLiteral
pub fn path_builder() -> TransactionLiteralFieldPathBuilder
impl TransactionLiteral
impl TransactionLiteral
pub const fn const_default() -> TransactionLiteral
pub fn negated_mut(&mut self) -> &mut bool
pub fn negated_mut(&mut self) -> &mut bool
Returns a mutable reference to negated.
If the field is unset, it is first initialized with the default value.
pub fn set_negated(&mut self, field: bool)
pub fn set_negated(&mut self, field: bool)
Sets negated with the provided value.
pub fn with_negated(self, field: bool) -> TransactionLiteral
pub fn with_negated(self, field: bool) -> TransactionLiteral
Sets negated with the provided value.
pub fn sender(&self) -> &SenderFilter
pub fn sender(&self) -> &SenderFilter
Returns the value of sender, or the default value if sender is unset.
pub fn sender_opt(&self) -> Option<&SenderFilter>
pub fn sender_opt(&self) -> Option<&SenderFilter>
pub fn sender_opt_mut(&mut self) -> Option<&mut SenderFilter>
pub fn sender_opt_mut(&mut self) -> Option<&mut SenderFilter>
pub fn sender_mut(&mut self) -> &mut SenderFilter
pub fn sender_mut(&mut self) -> &mut SenderFilter
Returns a mutable reference to sender.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn set_sender<T>(&mut self, field: T)where
T: Into<SenderFilter>,
pub fn set_sender<T>(&mut self, field: T)where
T: Into<SenderFilter>,
Sets sender with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn with_sender<T>(self, field: T) -> TransactionLiteralwhere
T: Into<SenderFilter>,
pub fn with_sender<T>(self, field: T) -> TransactionLiteralwhere
T: Into<SenderFilter>,
Sets sender with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn affected_address(&self) -> &AffectedAddressFilter
pub fn affected_address(&self) -> &AffectedAddressFilter
Returns the value of affected_address, or the default value if affected_address is unset.
pub fn affected_address_opt(&self) -> Option<&AffectedAddressFilter>
pub fn affected_address_opt(&self) -> Option<&AffectedAddressFilter>
pub fn affected_address_opt_mut(&mut self) -> Option<&mut AffectedAddressFilter>
pub fn affected_address_opt_mut(&mut self) -> Option<&mut AffectedAddressFilter>
pub fn affected_address_mut(&mut self) -> &mut AffectedAddressFilter
pub fn affected_address_mut(&mut self) -> &mut AffectedAddressFilter
Returns a mutable reference to affected_address.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn set_affected_address<T>(&mut self, field: T)where
T: Into<AffectedAddressFilter>,
pub fn set_affected_address<T>(&mut self, field: T)where
T: Into<AffectedAddressFilter>,
Sets affected_address with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn with_affected_address<T>(self, field: T) -> TransactionLiteralwhere
T: Into<AffectedAddressFilter>,
pub fn with_affected_address<T>(self, field: T) -> TransactionLiteralwhere
T: Into<AffectedAddressFilter>,
Sets affected_address with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn affected_object(&self) -> &AffectedObjectFilter
pub fn affected_object(&self) -> &AffectedObjectFilter
Returns the value of affected_object, or the default value if affected_object is unset.
pub fn affected_object_opt(&self) -> Option<&AffectedObjectFilter>
pub fn affected_object_opt(&self) -> Option<&AffectedObjectFilter>
pub fn affected_object_opt_mut(&mut self) -> Option<&mut AffectedObjectFilter>
pub fn affected_object_opt_mut(&mut self) -> Option<&mut AffectedObjectFilter>
pub fn affected_object_mut(&mut self) -> &mut AffectedObjectFilter
pub fn affected_object_mut(&mut self) -> &mut AffectedObjectFilter
Returns a mutable reference to affected_object.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn set_affected_object<T>(&mut self, field: T)where
T: Into<AffectedObjectFilter>,
pub fn set_affected_object<T>(&mut self, field: T)where
T: Into<AffectedObjectFilter>,
Sets affected_object with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn with_affected_object<T>(self, field: T) -> TransactionLiteralwhere
T: Into<AffectedObjectFilter>,
pub fn with_affected_object<T>(self, field: T) -> TransactionLiteralwhere
T: Into<AffectedObjectFilter>,
Sets affected_object with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn move_call(&self) -> &MoveCallFilter
pub fn move_call(&self) -> &MoveCallFilter
Returns the value of move_call, or the default value if move_call is unset.
pub fn move_call_opt(&self) -> Option<&MoveCallFilter>
pub fn move_call_opt(&self) -> Option<&MoveCallFilter>
pub fn move_call_opt_mut(&mut self) -> Option<&mut MoveCallFilter>
pub fn move_call_opt_mut(&mut self) -> Option<&mut MoveCallFilter>
pub fn move_call_mut(&mut self) -> &mut MoveCallFilter
pub fn move_call_mut(&mut self) -> &mut MoveCallFilter
Returns a mutable reference to move_call.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn set_move_call<T>(&mut self, field: T)where
T: Into<MoveCallFilter>,
pub fn set_move_call<T>(&mut self, field: T)where
T: Into<MoveCallFilter>,
Sets move_call with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn with_move_call<T>(self, field: T) -> TransactionLiteralwhere
T: Into<MoveCallFilter>,
pub fn with_move_call<T>(self, field: T) -> TransactionLiteralwhere
T: Into<MoveCallFilter>,
Sets move_call with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn emit_module(&self) -> &EmitModuleFilter
pub fn emit_module(&self) -> &EmitModuleFilter
Returns the value of emit_module, or the default value if emit_module is unset.
pub fn emit_module_opt(&self) -> Option<&EmitModuleFilter>
pub fn emit_module_opt(&self) -> Option<&EmitModuleFilter>
pub fn emit_module_opt_mut(&mut self) -> Option<&mut EmitModuleFilter>
pub fn emit_module_opt_mut(&mut self) -> Option<&mut EmitModuleFilter>
pub fn emit_module_mut(&mut self) -> &mut EmitModuleFilter
pub fn emit_module_mut(&mut self) -> &mut EmitModuleFilter
Returns a mutable reference to emit_module.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn set_emit_module<T>(&mut self, field: T)where
T: Into<EmitModuleFilter>,
pub fn set_emit_module<T>(&mut self, field: T)where
T: Into<EmitModuleFilter>,
Sets emit_module with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn with_emit_module<T>(self, field: T) -> TransactionLiteralwhere
T: Into<EmitModuleFilter>,
pub fn with_emit_module<T>(self, field: T) -> TransactionLiteralwhere
T: Into<EmitModuleFilter>,
Sets emit_module with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn event_type(&self) -> &EventTypeFilter
pub fn event_type(&self) -> &EventTypeFilter
Returns the value of event_type, or the default value if event_type is unset.
pub fn event_type_opt(&self) -> Option<&EventTypeFilter>
pub fn event_type_opt(&self) -> Option<&EventTypeFilter>
pub fn event_type_opt_mut(&mut self) -> Option<&mut EventTypeFilter>
pub fn event_type_opt_mut(&mut self) -> Option<&mut EventTypeFilter>
pub fn event_type_mut(&mut self) -> &mut EventTypeFilter
pub fn event_type_mut(&mut self) -> &mut EventTypeFilter
Returns a mutable reference to event_type.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn set_event_type<T>(&mut self, field: T)where
T: Into<EventTypeFilter>,
pub fn set_event_type<T>(&mut self, field: T)where
T: Into<EventTypeFilter>,
Sets event_type with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn with_event_type<T>(self, field: T) -> TransactionLiteralwhere
T: Into<EventTypeFilter>,
pub fn with_event_type<T>(self, field: T) -> TransactionLiteralwhere
T: Into<EventTypeFilter>,
Sets event_type with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn event_stream_head(&self) -> &EventStreamHeadFilter
pub fn event_stream_head(&self) -> &EventStreamHeadFilter
Returns the value of event_stream_head, or the default value if event_stream_head is unset.
pub fn event_stream_head_opt(&self) -> Option<&EventStreamHeadFilter>
pub fn event_stream_head_opt(&self) -> Option<&EventStreamHeadFilter>
pub fn event_stream_head_opt_mut(
&mut self,
) -> Option<&mut EventStreamHeadFilter>
pub fn event_stream_head_opt_mut( &mut self, ) -> Option<&mut EventStreamHeadFilter>
pub fn event_stream_head_mut(&mut self) -> &mut EventStreamHeadFilter
pub fn event_stream_head_mut(&mut self) -> &mut EventStreamHeadFilter
Returns a mutable reference to event_stream_head.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn set_event_stream_head<T>(&mut self, field: T)where
T: Into<EventStreamHeadFilter>,
pub fn set_event_stream_head<T>(&mut self, field: T)where
T: Into<EventStreamHeadFilter>,
Sets event_stream_head with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn with_event_stream_head<T>(self, field: T) -> TransactionLiteralwhere
T: Into<EventStreamHeadFilter>,
pub fn with_event_stream_head<T>(self, field: T) -> TransactionLiteralwhere
T: Into<EventStreamHeadFilter>,
Sets event_stream_head with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn package_write(&self) -> &PackageWriteFilter
pub fn package_write(&self) -> &PackageWriteFilter
Returns the value of package_write, or the default value if package_write is unset.
pub fn package_write_opt(&self) -> Option<&PackageWriteFilter>
pub fn package_write_opt(&self) -> Option<&PackageWriteFilter>
pub fn package_write_opt_mut(&mut self) -> Option<&mut PackageWriteFilter>
pub fn package_write_opt_mut(&mut self) -> Option<&mut PackageWriteFilter>
pub fn package_write_mut(&mut self) -> &mut PackageWriteFilter
pub fn package_write_mut(&mut self) -> &mut PackageWriteFilter
Returns a mutable reference to package_write.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn set_package_write<T>(&mut self, field: T)where
T: Into<PackageWriteFilter>,
pub fn set_package_write<T>(&mut self, field: T)where
T: Into<PackageWriteFilter>,
Sets package_write with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
pub fn with_package_write<T>(self, field: T) -> TransactionLiteralwhere
T: Into<PackageWriteFilter>,
pub fn with_package_write<T>(self, field: T) -> TransactionLiteralwhere
T: Into<PackageWriteFilter>,
Sets package_write with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
impl TransactionLiteral
impl TransactionLiteral
pub fn negate(self) -> TransactionLiteral
pub fn negate(self) -> TransactionLiteral
Negate this literal: require that its predicate not match.